-- -------------------------------------
-- Dataset 10.5281/zenodo.1167595
-- Naval Academy, France
-- Licence CC-BY-NC-SA-4.0
-- -------------------------------------

-- P1] AIS Status, Codes and Types --
--DROP SCHEMA IF EXISTS ais_status_codes_types CASCADE;

CREATE SCHEMA IF NOT EXISTS ais_status_codes_types
  AUTHORIZATION postgres;

DROP TABLE IF EXISTS ais_status_codes_types.aton;
DROP TABLE IF EXISTS ais_status_codes_types.mmsi_country_codes;
DROP TABLE IF EXISTS ais_status_codes_types.navigational_status;
DROP TABLE IF EXISTS ais_status_codes_types.ship_types;
DROP SEQUENCE IF EXISTS ais_status_codes_types.ship_types_detailed;

  
CREATE TABLE ais_status_codes_types.aton
  (
  nature text,
  id_code integer,
  definition text,
  CONSTRAINT aton_code_pkey PRIMARY KEY (id_code)    
  )
WITH (
  OIDS=FALSE
);
ALTER TABLE ais_status_codes_types.aton
  OWNER TO postgres;

COPY ais_status_codes_types.aton(
  nature, id_code, definition)
  FROM '<PATH_TO_DATASET>/[P1] AIS Status, Codes and Types/ATON.csv'
delimiter ';' csv header;

  
CREATE TABLE ais_status_codes_types.mmsi_country_codes
  (
  country_code integer,
  country text,
  CONSTRAINT country_code_pkey PRIMARY KEY (country_code)    
  )
WITH (
  OIDS=FALSE
);
ALTER TABLE ais_status_codes_types.mmsi_country_codes
  OWNER TO postgres;

COPY ais_status_codes_types.mmsi_country_codes(
  country_code, country)
  FROM '<PATH_TO_DATASET>/[P1] AIS Status, Codes and Types/MMSI Country Codes.csv'
delimiter ',' csv ;


  
CREATE TABLE ais_status_codes_types.navigational_status
  (
  id_status integer,
  definition text,
  CONSTRAINT id_status_pkey PRIMARY KEY (id_status)    
  )
WITH (
  OIDS=FALSE
);
ALTER TABLE ais_status_codes_types.navigational_status
  OWNER TO postgres;

COPY ais_status_codes_types.navigational_status(
  id_status, definition)
  FROM '<PATH_TO_DATASET>/[P1] AIS Status, Codes and Types/Navigational Status.csv'
delimiter ';' csv;


  
CREATE TABLE ais_status_codes_types.ship_types
  (
  id_shiptype integer,
  shiptype_min integer,
  shiptype_max integer,
  type_name text,
  ais_type_summary text,
  CONSTRAINT id_ship_types_pkey PRIMARY KEY (id_shiptype)    
  )
WITH (
  OIDS=FALSE
);
ALTER TABLE ais_status_codes_types.ship_types
  OWNER TO postgres;

COPY ais_status_codes_types.ship_types(
  id_shiptype,shiptype_min,shiptype_max,type_name,ais_type_summary
  )
  FROM '<PATH_TO_DATASET>/[P1] AIS Status, Codes and Types/Ship Types List.csv'
delimiter ',' csv header;

  
  
CREATE TABLE ais_status_codes_types.ship_types_detailed
  (
  id_detailedtype integer,
  detailed_type text,
  id_shiptype integer,
  CONSTRAINT id_detailedtype_pkey PRIMARY KEY (id_detailedtype), 
  CONSTRAINT ship_type_fk FOREIGN KEY (id_shiptype)     
      REFERENCES ais_status_codes_types.ship_types (id_shiptype)     
      ON DELETE CASCADE    
      ON UPDATE CASCADE       
  )
WITH (
  OIDS=FALSE
);
ALTER TABLE ais_status_codes_types.ship_types_detailed
  OWNER TO postgres;

COPY ais_status_codes_types.ship_types_detailed(
  id_detailedtype,detailed_type,id_shiptype
  )
  FROM '<PATH_TO_DATASET>/[P1] AIS Status, Codes and Types/Ship Types Detailed List.csv'
delimiter ',' csv header;